"use strict";
/*
 * Copyright 2020 NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const __1 = require("../");
const service_1 = require("../service");
class Compose extends command_1.Command {
    async run() {
        const { flags } = this.parse(Compose);
        const logger = __1.LoggerFactory.getLogger(__1.LogType.System, __1.BootstrapUtils.defaultWorkingDir);
        service_1.BootstrapCommandUtils.showBanner();
        flags.password = await service_1.BootstrapCommandUtils.resolvePassword(logger, flags.password, flags.noPassword, service_1.BootstrapCommandUtils.passwordPromptDefaultMessage, true);
        await new __1.BootstrapService(logger).compose(flags);
    }
}
exports.default = Compose;
Compose.description = 'It generates the `docker-compose.yml` file from the configured network.';
Compose.examples = [`$ symbol-bootstrap compose`];
Compose.flags = {
    help: service_1.BootstrapCommandUtils.helpFlag,
    target: service_1.BootstrapCommandUtils.targetFlag,
    password: service_1.BootstrapCommandUtils.passwordFlag,
    noPassword: service_1.BootstrapCommandUtils.noPasswordFlag,
    upgrade: command_1.flags.boolean({
        description: 'It regenerates the docker compose and utility files from the <target>/docker folder',
        default: __1.ComposeService.defaultParams.upgrade,
    }),
    user: command_1.flags.string({
        char: 'u',
        description: `User used to run the services in the docker-compose.yml file. "${__1.BootstrapUtils.CURRENT_USER}" means the current user.`,
        default: 'current',
    }),
};
