"use strict";
/*
 * Copyright 2020 NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoggerFactory = void 0;
const path_1 = require("path");
const winston = require("winston");
const LogType_1 = require("./LogType");
class LoggerFactory {
    static getLogger(id, workingDir) {
        if (!winston.loggers.has(id.toString())) {
            switch (id) {
                case LogType_1.LogType.System:
                    if (!workingDir) {
                        throw new Error('Working dir must be provided when using LogType.SYSTEM!');
                    }
                    winston.loggers.add(id.toString(), {
                        transports: [LoggerFactory.consoleTransport, LoggerFactory.fileTransport(path_1.join(workingDir, 'logs.log'))],
                        format: winston.format.label({ label: id.toString() }),
                    });
                    break;
                case LogType_1.LogType.Console:
                    winston.loggers.add(id.toString(), {
                        transports: [LoggerFactory.consoleOnlyTransport],
                        format: winston.format.label({ label: id.toString() }),
                    });
                    break;
                case LogType_1.LogType.ConsoleLog:
                    winston.loggers.add(id.toString(), {
                        transports: [LoggerFactory.consoleTransport],
                        format: winston.format.label({ label: id.toString() }),
                    });
                    break;
                case LogType_1.LogType.Silence:
                    winston.loggers.add(id.toString(), {
                        transports: [
                            new winston.transports.Console({
                                silent: true,
                            }),
                        ],
                        format: winston.format.label({ label: id.toString() }),
                    });
                    break;
                default:
                    throw new Error(`Unknown LogType ${id}`);
            }
        }
        return winston.loggers.get(id.toString());
    }
}
exports.LoggerFactory = LoggerFactory;
LoggerFactory.consoleTransport = new winston.transports.Console({
    format: winston.format.combine(winston.format.timestamp(), winston.format.cli(), winston.format.printf((i) => `${i.timestamp} ${i.level} ${i.message}`)),
});
LoggerFactory.consoleOnlyTransport = new winston.transports.Console({
    format: winston.format.combine(winston.format.printf((i) => `${i.message}`)),
});
LoggerFactory.fileTransport = (fileName) => new winston.transports.File({
    format: winston.format.combine(winston.format.timestamp(), winston.format.printf((i) => `${i.timestamp} ${i.level} ${i.message}`)),
    options: { flags: 'w' },
    filename: path_1.resolve(fileName),
    level: 'info',
});
