import { Account, NetworkType, PublicAccount } from 'symbol-sdk';
import { Logger } from '../logger';
import { Addresses, ConfigAccount, ConfigPreset, CustomPreset, NodeAccount, NodePreset, PrivateKeySecurityMode } from '../model';
import { AccountResolver } from './AccountResolver';
import { Migration, Password } from './BootstrapUtils';
import { KeyName } from './ConfigService';
export declare class ConfigLoader {
    private readonly logger;
    static presetInfoLogged: boolean;
    constructor(logger: Logger);
    generateRandomConfiguration(oldAddresses: Addresses | undefined, oldPresetData: ConfigPreset | undefined, presetData: ConfigPreset, accountResolver: AccountResolver): Promise<Addresses>;
    private resolveNemesisAccount;
    private sum;
    private processNemesisBalances;
    private getMaxHarvesterBalance;
    static shouldCreateNemesis(presetData: ConfigPreset): boolean;
    generateAddresses(networkType: NetworkType, privateKeySecurityMode: PrivateKeySecurityMode, accounts: number | string[]): ConfigAccount[];
    static toAccountFromKeys(networkType: NetworkType, publicKey: string | undefined, privateKey: string | undefined): PublicAccount | Account | undefined;
    static toConfigFromAccount(account: PublicAccount | Account): ConfigAccount;
    static toConfigFromKeys(networkType: NetworkType, publicKey: string | undefined, privateKey: string | undefined): ConfigAccount | undefined;
    resolveGenerateErrorMessage(keyName: KeyName, privateKeySecurityMode: PrivateKeySecurityMode): string | undefined;
    generateAccount(accountResolver: AccountResolver, networkType: NetworkType, privateKeySecurityMode: PrivateKeySecurityMode, keyName: KeyName, nodeName: string, oldStoredAccount: ConfigAccount | undefined, newProvidedAccount: ConfigAccount | undefined): Promise<ConfigAccount>;
    generateNodeAccount(accountResolver: AccountResolver, oldNodeAccount: NodeAccount | undefined, presetData: ConfigPreset, index: number, nodePreset: NodePreset, networkType: NetworkType): Promise<NodeAccount>;
    generateNodeAccounts(accountResolver: AccountResolver, oldAddresses: Addresses | undefined, presetData: ConfigPreset, networkType: NetworkType): Promise<NodeAccount[]>;
    private static getArray;
    loadCustomPreset(customPreset: string | undefined, password: Password): CustomPreset;
    static loadAssembly(preset: string, assembly: string, workingDir: string): CustomPreset;
    static loadNetworkPreset(preset: string, workingDir: string): CustomPreset;
    static loadSharedPreset(): CustomPreset;
    mergePresets<T extends CustomPreset>(object: T | undefined, ...otherArgs: (CustomPreset | undefined)[]): T;
    createPresetData(params: {
        workingDir: string;
        password: Password;
        preset?: string;
        assembly?: string;
        customPreset?: string;
        customPresetObject?: CustomPreset;
        oldPresetData?: ConfigPreset;
    }): ConfigPreset;
    dynamicDefaultNodeConfiguration(nodes?: Partial<NodePreset>[]): NodePreset[];
    private getDefaultConfiguration;
    static resolveRoles(nodePreset: NodePreset): string;
    expandRepeat(presetData: ConfigPreset): ConfigPreset;
    applyValueTemplate(context: any, value: any): any;
    expandServicesRepeat(context: any, services: any[]): any[];
    loadExistingPresetDataIfPreset(target: string, password: Password): ConfigPreset | undefined;
    loadExistingPresetData(target: string, password: Password): ConfigPreset;
    loadExistingAddressesIfPreset(target: string, password: Password): Addresses | undefined;
    migrateAddresses(addresses: any, networkType: NetworkType): Addresses;
    getAddressesMigration(networkType: NetworkType): Migration[];
    loadExistingAddresses(target: string, password: Password): Addresses;
    getGeneratedPresetLocation(target: string): string;
    getGeneratedAddressLocation(target: string): string;
}
