"use strict";
/*
 * Copyright 2021 NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.LinkService = void 0;
const __1 = require("../");
const BootstrapAccountResolver_1 = require("./BootstrapAccountResolver");
class LinkService {
    constructor(logger, params) {
        this.logger = logger;
        this.params = params;
        this.configLoader = new __1.ConfigLoader(logger);
    }
    async run(passedPresetData, passedAddresses) {
        const presetData = passedPresetData !== null && passedPresetData !== void 0 ? passedPresetData : this.configLoader.loadExistingPresetData(this.params.target, this.params.password);
        const addresses = passedAddresses !== null && passedAddresses !== void 0 ? passedAddresses : this.configLoader.loadExistingAddresses(this.params.target, this.params.password);
        const customPreset = this.configLoader.loadCustomPreset(this.params.customPreset, this.params.password);
        this.logger.info(`${this.params.unlink ? 'Unlinking' : 'Linking'} nodes`);
        const providedUrl = this.params.url;
        const urls = (this.params.useKnownRestGateways && presetData.knownRestGateways) || (providedUrl ? [providedUrl.replace(/\/$/, '')] : []);
        if (!urls.length) {
            throw new Error('URLs could not be resolved!');
        }
        const repositoryInfo = await new __1.RemoteNodeService(this.logger).getBestRepositoryInfo(urls);
        const repositoryFactory = repositoryInfo.repositoryFactory;
        await new __1.AnnounceService(this.logger, new BootstrapAccountResolver_1.BootstrapAccountResolver(this.logger)).announce(repositoryFactory, this.params.maxFee, this.params.ready, this.configLoader.mergePresets(presetData, customPreset), addresses, this);
    }
    createTransactions(params) {
        return new __1.LinkTransactionGenericFactory(this.logger, this.params.confirmUnlink(this.params), this.params.unlink).createTransactions(params);
    }
}
exports.LinkService = LinkService;
LinkService.defaultParams = {
    target: 'target',
    useKnownRestGateways: false,
    ready: false,
    url: 'http://localhost:3000',
    maxFee: 100000,
    unlink: false,
    confirmUnlink: (params) => () => Promise.resolve(params.removeOldLinked === undefined ? true : params.removeOldLinked),
};
