import { AccountInfo, Deadline, LinkAction, Transaction, UInt64 } from 'symbol-sdk';
import { Logger } from '../logger';
import { ConfigPreset, NodeAccount } from '../model';
import { TransactionFactory, VotingKeyAccount } from '../service';
export interface LinkServiceTransactionFactoryParams {
    presetData: ConfigPreset;
    nodeAccount: NodeAccount;
    mainAccountInfo: AccountInfo;
    deadline: Deadline;
    maxFee: UInt64;
    latestFinalizedBlockEpoch?: number;
}
export declare type KeyAccount = {
    publicKey: string;
};
export interface GenericNodeAccount {
    remote?: KeyAccount;
    vrf?: KeyAccount;
    voting?: VotingKeyAccount[];
}
export declare type ConfirmUnlink<T> = (accountName: string, alreadyLinkedAccount: T, print: (account: T) => string) => Promise<boolean>;
export declare class LinkTransactionGenericFactory implements TransactionFactory {
    private readonly logger;
    private readonly confirmUnlink;
    private readonly unlink;
    constructor(logger: Logger, confirmUnlink: ConfirmUnlink<any>, unlink: boolean);
    createTransactions({ presetData, nodeAccount, mainAccountInfo, deadline, maxFee, latestFinalizedBlockEpoch, }: LinkServiceTransactionFactoryParams): Promise<Transaction[]>;
    createGenericTransactions<AccountKL, VRFKL, VotingKL>(nodeName: string, currentMainAccountKeys: GenericNodeAccount, nodeAccount: GenericNodeAccount, latestFinalizedBlockEpoch: number, remoteTransactionFactory: (keyAccount: KeyAccount, action: LinkAction) => AccountKL, vrfTransactionFactory: (keyAccount: KeyAccount, action: LinkAction) => VRFKL, votingKeyTransactionFactory: (account: VotingKeyAccount, action: LinkAction) => VotingKL): Promise<(AccountKL | VRFKL | VotingKL)[]>;
    addVotingKeyLinkTransactions<T>(linkedVotingKeyAccounts: VotingKeyAccount[], votingKeyFiles: VotingKeyAccount[], nodeName: string, lastKnownNetworkEpoch: number, transactionFactory: (transaction: VotingKeyAccount, action: LinkAction) => T, print: (account: VotingKeyAccount) => string): Promise<T[]>;
    addVotingKeyUnlinkTransactions<T>(linkedVotingKeyAccounts: VotingKeyAccount[], votingKeyFiles: VotingKeyAccount[], nodeName: string, transactionFactory: (transaction: VotingKeyAccount, action: LinkAction) => T, print: (account: VotingKeyAccount) => string): Promise<T[]>;
    static overlapsVotingAccounts(x: VotingKeyAccount, y: VotingKeyAccount): boolean;
    private addTransaction;
}
