import { Logger } from '../logger';
export interface VerifyReport {
    platform: string;
    lines: ReportLine[];
}
export interface ReportLine {
    header: string;
    message: string;
    recommendation?: string;
}
export interface ExpectedVersions {
    node: string;
    docker: string;
    dockerCompose: string;
    symbolBootstrap?: string;
}
export declare class VerifyService {
    private readonly logger;
    private readonly expectedVersions;
    readonly semverOptions: {
        loose: boolean;
    };
    constructor(logger: Logger, expectedVersions?: Partial<ExpectedVersions>);
    createReport(): Promise<VerifyReport>;
    logReport(report: VerifyReport, logger: Logger): void;
    loadVersion(text: string): string | undefined;
    testNodeJs(expectedVersion: string): Promise<ReportLine>;
    testDocker(expectedVersion: string): Promise<ReportLine>;
    testDockerCompose(expectedVersion: string): Promise<ReportLine>;
    testSymbolBootstrap(expectedVersion: string): Promise<ReportLine>;
    testDockerRun(): Promise<ReportLine>;
    testSudo(): Promise<ReportLine>;
    loadVersionFromCommand(command: string): Promise<string | undefined>;
    private verifyInstalledApp;
}
